==> owncloud-10.0.7.zip: owncloud/lib/l10n/ka_GE.js <==
OC.L10N.register(
    "lib",
    {
    "today" : "დღეს",
    "yesterday" : "გუშინ",
    "last month" : "გასულ თვეში",
    "last year" : "ბოლო წელს",
    "seconds ago" : "წამის წინ",
    "None" : "არა",
    "Username" : "მომხმარებლის სახელი",
    "Password" : "პაროლი",
    "Apps" : "აპლიკაციები",
    "General" : "ზოგადი",
    "Storage" : "საცავი",
    "Security" : "უსაფრთხოება",
    "Encryption" : "ენკრიპცია",
    "Sharing" : "გაზიარება",
    "Search" : "ძებნა",
    "%s enter the database username." : "%s შეიყვანეთ ბაზის იუზერნეიმი.",
    "%s enter the database name." : "%s შეიყვანეთ ბაზის სახელი.",
    "%s you may not use dots in the database name" : "%s არ მიუთითოთ წერტილი ბაზის სახელში",
    "Oracle username and/or password not valid" : "Oracle იუზერნეიმი და/ან პაროლი არ არის სწორი",
    "DB Error: \"%s\"" : "DB შეცდომა: \"%s\"",
    "Offending command was: \"%s\"" : "Offending ბრძანება იყო: \"%s\"",
    "You need to enter either an existing account or the administrator." : "თქვენ უნდა შეიყვანოთ არსებული მომხმარებელის სახელი ან ადმინისტრატორი.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Offending ბრძანება იყო: \"%s\", სახელი: %s, პაროლი: %s",
    "PostgreSQL username and/or password not valid" : "PostgreSQL იუზერნეიმი და/ან პაროლი არ არის სწორი",
    "Set an admin username." : "დააყენეთ ადმინისტრატორის სახელი.",
    "Set an admin password." : "დააყენეთ ადმინისტრატორის პაროლი.",
    "Could not find category \"%s\"" : "\"%s\" კატეგორიის მოძებნა ვერ მოხერხდა",
    "A valid username must be provided" : "უნდა მიუთითოთ არსებული მომხმარებლის სახელი",
    "A valid password must be provided" : "უნდა მიუთითოთ არსებული პაროლი",
    "Help" : "დახმარება",
    "Settings" : "პარამეტრები",
    "Users" : "მომხმარებელი",
    "web services under your control" : "web services under your control",
    "Application is not enabled" : "აპლიკაცია არ არის აქტიური",
    "Authentication error" : "ავთენტიფიკაციის შეცდომა",
    "Token expired. Please reload page." : "Token–ს ვადა გაუვიდა. გთხოვთ განაახლოთ გვერდი."
},
"nplurals=1; plural=0;");

==> owncloud-10.4.0.zip: owncloud/lib/l10n/ka_GE.js <==
OC.L10N.register(
    "lib",
    {
    "today" : "დღეს",
    "yesterday" : "გუშინ",
    "last month" : "გასულ თვეში",
    "last year" : "ბოლო წელს",
    "seconds ago" : "წამის წინ",
    "None" : "არა",
    "Username" : "მომხმარებლის სახელი",
    "Password" : "პაროლი",
    "__language_name__" : "__language_name__",
    "Apps" : "აპლიკაციები",
    "General" : "ზოგადი",
    "Storage" : "საცავი",
    "Security" : "უსაფრთხოება",
    "Encryption" : "ენკრიპცია",
    "Sharing" : "გაზიარება",
    "Search" : "ძებნა",
    "%s enter the database username." : "%s შეიყვანეთ ბაზის იუზერნეიმი.",
    "%s enter the database name." : "%s შეიყვანეთ ბაზის სახელი.",
    "%s you may not use dots in the database name" : "%s არ მიუთითოთ წერტილი ბაზის სახელში",
    "Oracle username and/or password not valid" : "Oracle იუზერნეიმი და/ან პაროლი არ არის სწორი",
    "DB Error: \"%s\"" : "DB შეცდომა: \"%s\"",
    "Offending command was: \"%s\"" : "Offending ბრძანება იყო: \"%s\"",
    "You need to enter either an existing account or the administrator." : "თქვენ უნდა შეიყვანოთ არსებული მომხმარებელის სახელი ან ადმინისტრატორი.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Offending ბრძანება იყო: \"%s\", სახელი: %s, პაროლი: %s",
    "PostgreSQL username and/or password not valid" : "PostgreSQL იუზერნეიმი და/ან პაროლი არ არის სწორი",
    "Set an admin username." : "დააყენეთ ადმინისტრატორის სახელი.",
    "Set an admin password." : "დააყენეთ ადმინისტრატორის პაროლი.",
    "Could not find category \"%s\"" : "\"%s\" კატეგორიის მოძებნა ვერ მოხერხდა",
    "A valid username must be provided" : "უნდა მიუთითოთ არსებული მომხმარებლის სახელი",
    "A valid password must be provided" : "უნდა მიუთითოთ არსებული პაროლი",
    "Settings" : "პარამეტრები",
    "Users" : "მომხმარებელი",
    "Imprint" : "ბეჭედი",
    "Application is not enabled" : "აპლიკაცია არ არის აქტიური",
    "Authentication error" : "ავთენტიფიკაციის შეცდომა",
    "Token expired. Please reload page." : "Token–ს ვადა გაუვიდა. გთხოვთ განაახლოთ გვერდი."
},
"nplurals=2; plural=(n!=1);");
